.. currentmodule:: abjad.tools.scoretools

fill_measures_in_expr_with_full_measure_spacer_skips
====================================================

.. autofunction:: fill_measures_in_expr_with_full_measure_spacer_skips
